'''自定义类型注释'''

from typing import Any, Union
import requests


Response = requests.models.Response
